tiled.media\_type\_registration.SerializationRegistry
=====================================================

.. currentmodule:: tiled.media_type_registration

.. autoclass:: SerializationRegistry

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SerializationRegistry.__init__
      ~SerializationRegistry.aliases
      ~SerializationRegistry.dispatch
      ~SerializationRegistry.media_types
      ~SerializationRegistry.register
      ~SerializationRegistry.register_alias
      ~SerializationRegistry.resolve_alias
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SerializationRegistry.DEFAULT_ALIASES
      ~SerializationRegistry.structure_families
   
   